@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.101 2006/01/12 17:14:23 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.103 2006/01/23 16:05:35 richb Exp $
  *
  *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -167,8 +167,8 @@ struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
     number
 },
 {
-    /* Note to translators: this is a division sign (/) */
-    N_("\342\210\225"),
+    /* Note to translators: this is a division sign (÷) */
+    N_("\303\267"),
     N_("Divide"),
     NULL,
     { 0,         GDK_SHIFT_MASK, 0,             0,      GDK_SHIFT_MASK, 0 },
@@ -375,7 +375,7 @@ struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
     '-',
     M_NONE,
     do_calc,
-    NULL,
+    N_("-"),
     unop | binop
 },
 {
@@ -400,7 +400,7 @@ struct button a_buttons[A_NOBUTTONS] = {   /* Advanced mode button values. */
     's',
     M_NONE,
     do_immed, 
-    NULL,
+    N_("Sqrt"),
     func
 },
 {
